@@ -8,11 +8,6 @@ from django.conf import settings
 from easy_thumbnails.files import get_thumbnailer
 from easy_thumbnails.source_generators import pil_image
 
-try:
-    from PIL import Image
-except ImportError:
-    import Image
-
 logger = logging.getLogger(__name__)
 
 
@@ -41,6 +36,7 @@ def get_attrs(image, name):
             # open image and rotate according to its exif.orientation
             width, height = pil_image(image).size
         except AttributeError:
+            # invalid image -> AttributeError
             width = image.width
             height = image.height
 
@@ -51,7 +47,7 @@ def get_attrs(image, name):
             'data-org-width': width,
             'data-org-height': height,
         }
-    except ValueError:
+    except (ValueError, AttributeError):
         # can't create thumbnail from image
         return {}
 
@@ -104,7 +100,8 @@ class CropForeignKeyWidget(ForeignKeyRawIdWidget, CropWidget):
                     get_model(app_name, model_name).objects.get(pk=value),
                     self.field_name,
                 )
-                attrs.update(get_attrs(image, name))
+                if image:
+                    attrs.update(get_attrs(image, name))
             except ObjectDoesNotExist:
                 logger.error("Can't find object: %s.%s with primary key %s "
                              "for cropping." % (app_name, model_name, value))
